@@ -1,7 +1,7 @@
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class AdminSSOConfig(AppConfig):
-    name = 'admin_sso'
+    name = "admin_sso"
     verbose_name = _("Admin Single Sign-On")
